from setuptools import setup
setup(name='pyseparator',
      version='0.12',
      description='pyseparator',
      author='lijun',
      license='MIT',
      author_email='asdfzxcvqwer123a@126.com',
      packages=['pyseparator'],
      zip_safe=False)